@@ -558,6 +558,13 @@ func (ccs ChangeCharSet) Clause(_ StatementModifiers) string {
 	if ccs.FromCollation == ccs.ToCollation {
 		return ""
 	}
+	if strings.HasPrefix(ccs.FromCollation, "utf8mb3_") || strings.HasPrefix(ccs.ToCollation, "utf8mb3_") {
+		fromNormalized := strings.Replace(ccs.FromCollation, "utf8_", "utf8mb3_", 1)
+		toNormalized := strings.Replace(ccs.ToCollation, "utf8_", "utf8mb3_", 1)
+		if fromNormalized == toNormalized {
+			return ""
+		}
+	}
 	return fmt.Sprintf("DEFAULT CHARACTER SET = %s COLLATE = %s", ccs.ToCharSet, ccs.ToCollation)
 }
 
@@ -643,6 +650,27 @@ func (cc ChangeComment) Clause(_ StatementModifiers) string {
 	return fmt.Sprintf("COMMENT '%s'", EscapeValueForCreateTable(cc.NewComment))
 }
 
+///// ChangeTablespace /////////////////////////////////////////////////////////
+
+// ChangeTablespace represents a difference in the table's TABLESPACE clause
+// between two versions of a table. It satisfies the TableAlterClause interface.
+type ChangeTablespace struct {
+	NewTablespace string
+}
+
+// Clause returns a clause of an ALTER TABLE statement that changes a table's
+// tablespace.
+func (ct ChangeTablespace) Clause(_ StatementModifiers) string {
+	// Once an explicit tablespace name has been specified, there's no way to
+	// hide it again. Table.Diff will still generate a ChangeTablespace value,
+	// which avoids the "unsupported diff due to no clauses generated" check,
+	// but there's nothing to actually run.
+	if ct.NewTablespace == "" {
+		return ""
+	}
+	return "TABLESPACE " + EscapeIdentifier(ct.NewTablespace)
+}
+
 ///// ChangeStorageEngine //////////////////////////////////////////////////////
 
 // ChangeStorageEngine represents a difference in the table's storage engine.
