@@ -85,8 +85,8 @@ type Options struct {
 	DefaultConnParams   string // only TypeLocalDocker
 	RootPassword        string // only TypeLocalDocker
 	NameCaseMode        tengo.NameCaseMode
-	PrefabWorkspace     Workspace // only TypePrefab
-	LockWaitTimeout     time.Duration
+	PrefabWorkspace     Workspace     // only TypePrefab
+	LockTimeout         time.Duration // max wait for workspace user-level locking, via GET_LOCK()
 	Concurrency         int
 	SkipBinlog          bool
 }
@@ -116,10 +116,10 @@ func OptionsForDir(dir *fs.Dir, instance *tengo.Instance) (Options, error) {
 		return Options{}, err
 	}
 	opts := Options{
-		CleanupAction:   CleanupActionNone,
-		SchemaName:      dir.Config.Get("temp-schema"),
-		LockWaitTimeout: 30 * time.Second,
-		Concurrency:     10,
+		CleanupAction: CleanupActionNone,
+		SchemaName:    dir.Config.Get("temp-schema"),
+		LockTimeout:   30 * time.Second,
+		Concurrency:   10,
 	}
 	if requestedType == "docker" {
 		opts.Type = TypeLocalDocker
@@ -268,7 +268,7 @@ func (wsSchema *Schema) FailedKeys() (result []tengo.ObjectKey) {
 // only represents fatal errors that prevented the entire process.
 // Note that if opts.NameCaseMode > tengo.NameCaseAsIs, logicalSchema may be
 // modified in-place to force some identifiers to lowercase.
-func ExecLogicalSchema(logicalSchema *fs.LogicalSchema, opts Options) (wsSchema *Schema, fatalErr error) {
+func ExecLogicalSchema(logicalSchema *fs.LogicalSchema, opts Options) (_ *Schema, retErr error) {
 	if logicalSchema.CharSet != "" {
 		opts.DefaultCharacterSet = logicalSchema.CharSet
 	}
@@ -281,18 +281,25 @@ func ExecLogicalSchema(logicalSchema *fs.LogicalSchema, opts Options) (wsSchema
 		}
 	}
 
-	var ws Workspace
-	ws, fatalErr = New(opts)
-	if fatalErr != nil {
-		return
+	ws, err := New(opts)
+	if err != nil {
+		return nil, err
 	}
-	wsSchema = &Schema{
+
+	// ExecLogicalSchema names its error return so that a deferred func can check
+	// if an error occurred, but otherwise intentionally does not use named return
+	// variables, and instead declares new local vars for all other usage. This is
+	// to avoid mistakes with variable shadowing, nil pointer panics, etc which are
+	// common when dealing with named returns and deferred anonymous functions.
+	wsSchema := &Schema{
 		LogicalSchema: logicalSchema,
 		Failures:      []*StatementError{},
 	}
 	defer func() {
-		if cleanupErr := ws.Cleanup(wsSchema.Schema); fatalErr == nil {
-			fatalErr = cleanupErr
+		cleanupErr := ws.Cleanup(wsSchema.Schema)
+		// We only care about a cleanup error if the original returned error was nil
+		if retErr == nil && cleanupErr != nil {
+			retErr = cleanupErr
 		}
 	}()
 
@@ -328,14 +335,14 @@ func ExecLogicalSchema(logicalSchema *fs.LogicalSchema, opts Options) (wsSchema
 
 	// Examine statement errors. If any deadlocks occurred, retry them
 	// sequentially, since some deadlocks are expected from concurrent CREATEs in
-	// MySQL 8+ if FKs are present. Also retry errors from CREATE TABLE...LIKE
-	// being run out-of-order (only once though; nested chains of CREATE TABLE...
-	// LIKE are unsupported)
+	// MySQL 8+ if FKs are present. Ditto with metadata lock wait timeouts.
+	// Also retry errors from CREATE TABLE...LIKE being run out-of-order (only once
+	// though; nested chains of CREATE TABLE...LIKE are unsupported)
 	sequentialStatements := []*fs.Statement{}
 	for n := 0; n < len(logicalSchema.Creates); n++ {
 		if err := <-errs; err != nil {
 			stmterr := err.(*StatementError)
-			if tengo.IsDatabaseError(stmterr.Err, mysqlerr.ER_LOCK_DEADLOCK, mysqlerr.ER_NO_SUCH_TABLE) {
+			if tengo.IsDatabaseError(stmterr.Err, mysqlerr.ER_LOCK_DEADLOCK, mysqlerr.ER_LOCK_WAIT_TIMEOUT, mysqlerr.ER_NO_SUCH_TABLE) {
 				sequentialStatements = append(sequentialStatements, stmterr.Statement)
 			} else {
 				wsSchema.Failures = append(wsSchema.Failures, stmterr)
@@ -354,8 +361,8 @@ func ExecLogicalSchema(logicalSchema *fs.LogicalSchema, opts Options) (wsSchema
 		}
 	}
 
-	wsSchema.Schema, fatalErr = ws.IntrospectSchema()
-	return
+	wsSchema.Schema, err = ws.IntrospectSchema()
+	return wsSchema, err
 }
 
 func wrapFailure(statement *fs.Statement, err error) *StatementError {
